#importing the necessary libraries
import pandas as pd
from pandas_profiling import ProfileReport

class xplore:
    def __init__(self, data):
        #writing the pop-up vscode  guide as a block comment
        '''
        xplore is a python package built with pandas for light-weight python projects in data science and analytics, AI and ML.\n
        The xplore() function takes the argument of whatever variable assigned to the read file path/url of a labelled dataset.\n
        xplore converts the labelled dataset to a DataFrame and performs some predefined exploratory data analysis on the dataset.
        '''
        #converting the structured data to a dataframe
        data = pd.DataFrame(data)
        print('------------------------------------')
        print('The fist 5 entries of your dataset are:\n')
        print(data.head()) #printing the first 5 entries of the dataset
        print('\n')

        print('------------------------------------')
        print('The last 5 entries of your dataset are:\n')
        print(data.tail()) #printing the last 5 entries of the dataset
        print('\n')

        print('------------------------------------')
        print('Stats on your dataset:\n')
        print(data.describe) #printing a descriptipn of the dataset
        print('\n')

        print('------------------------------------')
        print('The Value types of each column are:\n')
        print(data.dtypes) #printing value types of each column
        print('\n')

        print('------------------------------------')
        print('Info on your Dataset:\n')
        print(data.info) #printing value types of each column
        print('\n')

        print('------------------------------------')
        print('The shape of your dataset in the order of rows and columns is:\n')
        print(data.shape) #printing the shape of the dataset
        print('\n')

        print('------------------------------------')
        print('The features of your dataset are:\n')
        print(data.columns) #printing features
        print('\n')

        print('------------------------------------')
        print('The total number of null values from individual columns of your data set are:\n')
        print(data.isnull().sum()) #printing the total number of null values in the dataset
        print('\n')

        print('------------------------------------')
        print('The number of rows in your dataset are:\n')
        print(len(data)) #printing number of rows
        print('\n')

        print('------------------------------------')
        print('The values in your dataset are:\n')
        print(data.values) #printing values
        print('\n')
    
        print('------------------------------------')
        print('\n')
        print('Do you want to generate a detailed report on the exploration of your dataset?')
        response = input('[y/n]: ').lower()

        if response == 'y' or response == 'yes':
            print("Generating report...", '\n')
            prof = ProfileReport(data)
            prof.to_file(output_file='output.html')
            print('Your Report has been generated and saved as \'output.html\'')

        elif response == 'n' or response == 'no':

            print('Process Completed')

        else:
            print('Process Completed')

#df = pd.read_csv('tests/fifa_ranking.csv')
#xplore(df)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="xplore",
    packages = ['xplore'],
    version="0.0.1",
    author="Jerry Buaba",
    author_email="buabajerry@gmail.com",
    description="A python package built with pandas for data scientist/analysts, AI/ML engineers for exploring features of a dataset in minimal number of lines of code for quick analysis before data wrangling and feature extraction.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/buabaj/xplore",
    download_url='https://github.com/buabaj/xplore/archive/v0.0.1.tar.gz',
    keywords = ['Data-Science', 'Machine-Learning', 'python'],
    install_requires=[            
          'pandas',
          'pandas_profiling',
      ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)